<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Vet</translation>
    </message>
    <message>
        <location filename="../../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Schuin</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../../ui_obconf.h" line="1012"/>
        <source>Window Manager Preferences</source>
        <translation>Instellingen van vensterbeheerder Openbox</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1017"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1019"/>
        <source>Appearance</source>
        <translation>Uiterlijk</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1021"/>
        <source>Font</source>
        <translation>Lettertype</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1023"/>
        <location filename="../../ui_obconf.h" line="1038"/>
        <source>Windows</source>
        <translation>Vensters</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1025"/>
        <source>Move &amp; Resize</source>
        <translation>Verplaatsen en herschalen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1027"/>
        <source>Mouse</source>
        <translation>Muis</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1029"/>
        <source>Desktops</source>
        <translation>Werkbladen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1031"/>
        <source>Margins</source>
        <translation>Randen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1033"/>
        <source>Dock</source>
        <translation>Dok</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1036"/>
        <source>&amp;Install a new theme...</source>
        <translation>Nieuw thema &amp;installeren...</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1037"/>
        <source>Create a theme &amp;archive (.obt)...</source>
        <translation>Thema-archief &amp;maken (.obt)...</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1039"/>
        <source>&amp;Windows retain a border when undecorated</source>
        <translation>&amp;Vensters behouden een rand wanneer niet versierd</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1040"/>
        <source>A&amp;nimate iconify and restore</source>
        <translation>&amp;Animeer minimaliseren en herstellen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1041"/>
        <source>Window Titles</source>
        <translation>Venstertitels</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1042"/>
        <source>Button order:</source>
        <translation>Knopvolgorde:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1043"/>
        <source>N: Window icon
L: Window label (Title)
I: Iconify (Minimize)
M: Maximize
C: Close
S: Shade (Roll up)
D: Omnipresent (On all desktops)</source>
        <translation>N: Vensterpictogram
L: Venstertitel
I: Minimaliseren
M: Maximaliseren
C: Sluiten
S: Oprollen
D: Aanwezig op alle werkbladen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1056"/>
        <source>&amp;Active window title: </source>
        <translation>Titel van &amp;actieve venster</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1057"/>
        <source>&amp;Inactive window title: </source>
        <translation>Titel van &amp;inactieve venster</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1058"/>
        <source>Menu &amp;header: </source>
        <translation>Menu&amp;kop</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1059"/>
        <source>&amp;Menu Item: </source>
        <translation>&amp;Menu-onderdeel:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1060"/>
        <source>Active &amp;On-screen display: </source>
        <translation>A&amp;ctieve beeldschermvertoning:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1061"/>
        <source>Inactive O&amp;n-screen display: </source>
        <translation>I&amp;nactieve beelschermvertoning:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1062"/>
        <source>Focus &amp;new windows when they appear</source>
        <translation>&amp;Stel scherp op nieuwe vensters wanneer zij verschijnen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1063"/>
        <source>&amp;Place new windows under the mouse pointer</source>
        <translation>&amp;Plaats nieuwe vensters onder de muisaanwijzer</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1064"/>
        <source>&amp;Center new windows when they are placed</source>
        <translation>&amp;Centreer nieuwe vensters wanneer ze worden geplaatst</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1065"/>
        <source>Prefer to place new windows &amp;on:</source>
        <translation>Plaats &amp;nieuwe vensters bij voorkeur op:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1068"/>
        <source>All monitors</source>
        <translation>alle beeldschermen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1069"/>
        <source>The active monitor</source>
        <translation>het actieve beeldscherm</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1070"/>
        <source>The monitor with the mouse</source>
        <translation>het beeldscherm waar de muispijl zich bevindt</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1071"/>
        <source>Primary monitor</source>
        <translation>het primaire beeldscherm</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1073"/>
        <source>Primary Monitor</source>
        <translation>Primaire beeldscherm</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1074"/>
        <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
        <translation>Het primaire beeldscherm is waar Openbox dialoogvensters plaatst, zoals dat wat wordt gebruikt voor vensterwisseling.</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1075"/>
        <source>Primary &amp;monitor:</source>
        <translation>&amp;Primair beeldscherm</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1078"/>
        <source>Fixed Monitor</source>
        <translation>Vastgezet beeldscherm</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1079"/>
        <source>Active Monitor</source>
        <translation>Actief beeldscherm</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1080"/>
        <source>Monitor With Mouse Pointer</source>
        <translation>Beeldscherm met muisaanwijzer</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1082"/>
        <source>&amp;Fixed monitor:</source>
        <translation>&amp;Vastgezet beeldscherm:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1083"/>
        <source>Moving and Resizing Windows</source>
        <translation>Verplaatsen en herschalen van vensters</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1084"/>
        <source>Update the window contents while &amp;resizing</source>
        <translation>Werk de vensterinhoud bij tijdens &amp;herschalen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1085"/>
        <source>Drag &amp;threshold distance:</source>
        <translation>Afstand voor &amp;sleepdrempel:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1086"/>
        <source>Amount of resistance against other &amp;windows:</source>
        <translation>Hoeveelheid weerstand tegen andere &amp;vensters:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1087"/>
        <source>Amount of resistance against screen &amp;edges:</source>
        <translation>Hoeveelheid weerstand tegen &amp;beeldschermranden:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1088"/>
        <source>&amp;Amount of time to wait before switching:</source>
        <translation>Hoeveelheid ver&amp;traging voor wisselen:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1089"/>
        <source>&amp;Switch desktops when moving a window past the screen edge</source>
        <translation>&amp;Wissel werkbladen wanneer een venster voorbij de schermrand wordt verplaatst</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1090"/>
        <source>Information Dialog</source>
        <translation>Informatiedialoog</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1093"/>
        <location filename="../../ui_obconf.h" line="1100"/>
        <source>Centered</source>
        <translation>Gecentreerd</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1094"/>
        <source>From left edge</source>
        <translation>Vanaf de linkerrand</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1095"/>
        <source>From right edge</source>
        <translation>Vanaf de rechterrand</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1097"/>
        <source>Fixed &amp;y position:</source>
        <translation>Vaste &amp;y-positie (pixel):</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1101"/>
        <source>From top edge</source>
        <translation>Vanaf de bovenrand</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1102"/>
        <source>From bottom edge</source>
        <translation>Vanaf de onderrand</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1104"/>
        <source>Information dialog&apos;s &amp;position:</source>
        <translation>&amp;Positie van de informatiedialoog</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1105"/>
        <source>Fixed &amp;x position:</source>
        <translation>Vaste &amp;x-positie (pixel):</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1106"/>
        <source>Show &amp;information dialog:</source>
        <translation>Toon &amp;informatiedialoog:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1109"/>
        <source>When resizing terminal windows</source>
        <translation>Bij herschalen van terminalvensters</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1110"/>
        <source>Always</source>
        <translation>Altijd</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1111"/>
        <source>Never</source>
        <translation>Nooit</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1115"/>
        <source>Centered on the window</source>
        <translation>Gecentreerd op het venster</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1116"/>
        <source>Above the window</source>
        <translation>Boven het venster</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1117"/>
        <source>Fixed position on screen</source>
        <translation>Vaste positie op het scherm</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1119"/>
        <source>Focusing Windows</source>
        <translation>Scherpstellen op vensters</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1120"/>
        <source>Focus windows when the mouse pointer moves over them</source>
        <translation>Stel &amp;scherp op vensters wanneer de muispijl erover beweegt</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1121"/>
        <source>&amp;Delay before focusing and raising windows:</source>
        <translation>&amp;Vertraging voor scherpstellen en verheffen van vensters:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1122"/>
        <source>Move focus under the mouse when &amp;switching desktops</source>
        <translation>Plaats scherpstelling onder de muispijl &amp;bij wisselen van werkbladen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1123"/>
        <source>Move focus &amp;under the mouse when the mouse is not moving</source>
        <translation>Plaats scherpstelling &amp;onder de muispijl, wanneer die niet beweegt</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1124"/>
        <source>&amp;Raise windows when the mouse pointer moves over them</source>
        <translation>Verhef ven&amp;sters wanneer de muispijl over hen beweegt</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1125"/>
        <source>Titlebar</source>
        <translation>Titelbalk</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1126"/>
        <source>Double click on the &amp;titlebar:</source>
        <translation>Dubbelklikken op de &amp;titelbalk:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1129"/>
        <source>Maximizes the window</source>
        <translation>Maximaliseert het venster</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1130"/>
        <source>Shades the window</source>
        <translation>Rolt het venster op</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1132"/>
        <source>Double click ti&amp;me:</source>
        <translation>&amp;Tussenpoze voor dubbelklik:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1133"/>
        <source>&amp;Show a notification when switching desktops</source>
        <translation>Toon een melding bij &amp;wisselen van werkbladen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1134"/>
        <source>&amp;Amount of time to show the notification for:</source>
        <translation>&amp;Hoe lang de melding wordt getoond:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1135"/>
        <source>&amp;Number of desktops: </source>
        <translation>Aan&amp;tal werkbladen: </translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1136"/>
        <source>&amp;Desktop names:</source>
        <translation>&amp;Namen van werkbladen:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1137"/>
        <source>Desktop Margins</source>
        <translation>Werkbladranden</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1138"/>
        <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
        <translation>Werkbladranden zijn gereserveerde gebieden op de rand van uw scherm. Nieuwe vensters zullen niet binnen een rand worden geplaatst, en gemaximaliseerde vensters zullen hen niet bedekken.</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1139"/>
        <source>Left:</source>
        <translation>Links:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1140"/>
        <location filename="../../ui_obconf.h" line="1142"/>
        <location filename="../../ui_obconf.h" line="1144"/>
        <location filename="../../ui_obconf.h" line="1146"/>
        <source>px</source>
        <translation>Pixel (px)</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1141"/>
        <source>Top:</source>
        <translation>Bovenaan:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1143"/>
        <source>Right:</source>
        <translation>Rechts:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1145"/>
        <source>Bottom:</source>
        <translation>Onderaan:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1147"/>
        <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
        <translation>Het dok is een speciaal grafisch &apos;vat&apos; voor doktoepassingen. Het is niet zichtbaar op het scherm, totdat er een doktoepassing wordt gedraaid. Doktoepassingen kunnen worden gebruikt om dingen te tonen zoals een klok, of om u een systeemvak te bieden.</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1148"/>
        <source>Position</source>
        <translation>Positie</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1149"/>
        <source>&amp;Position:</source>
        <translation>&amp;Positie:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1152"/>
        <source>Top Left</source>
        <translation>Linksboven</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1153"/>
        <source>Top</source>
        <translation>Middenboven</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1154"/>
        <source>Top Right</source>
        <translation>Rechtsboven</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1155"/>
        <source>Left</source>
        <translation>Linksmidden (verticaal)</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1156"/>
        <source>Right</source>
        <translation>Rechtsmidden (verticaal)</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1157"/>
        <source>Bottom Left</source>
        <translation>Linksonder</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1158"/>
        <source>Bottom</source>
        <translation>Middenonder</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1159"/>
        <source>Bottom Right</source>
        <translation>Rechtsonder</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1160"/>
        <source>Floating</source>
        <translation>Handmatig vastgelegde positie</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1162"/>
        <source>&amp;Floating position:</source>
        <translation>&amp;Handmatig vastgelegde positie:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1163"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1164"/>
        <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
        <translation>Sta toe dat &amp;vensters worden geplaatst binnen het dokgebied</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1165"/>
        <source>&amp;Orientation: </source>
        <translation>Oriëntatie:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1168"/>
        <source>Vertical</source>
        <translation>verticaal</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1169"/>
        <source>Horizontal</source>
        <translation>horizontaal</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1171"/>
        <source>Stacking</source>
        <translation>Stapelen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1172"/>
        <source>Keep dock &amp;above other windows</source>
        <translation>Houd dok altijd op de voor&amp;grond</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1173"/>
        <source>A&amp;llow dock to be both above and below windows</source>
        <translation>Sta toe dat dok zich boven en onder vensters bevindt</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1174"/>
        <source>Keep dock &amp;below other windows</source>
        <translation>Houd dok altijd op de &amp;achtergrond</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1175"/>
        <source>Hiding</source>
        <translation>Verbergen</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1176"/>
        <source>&amp;Delay before hiding:</source>
        <translation>Vertraging voor ver&amp;bergen:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1177"/>
        <source>Delay before &amp;showing:</source>
        <translation>Vertraging voor &amp;tonen:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1178"/>
        <source>&amp;Hide off screen</source>
        <translation>Verbergen a&amp;ctiveren</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1179"/>
        <source>About</source>
        <translation>&amp;Over</translation>
    </message>
</context>
<context>
    <name>Obconf::MainDialog</name>
    <message>
        <location filename="../../theme.cpp" line="150"/>
        <location filename="../../theme.cpp" line="160"/>
        <source>Choose an Openbox theme</source>
        <translation>Kies een thema voor Openbox</translation>
    </message>
    <message>
        <location filename="../../desktops.cpp" line="65"/>
        <location filename="../../desktops.cpp" line="87"/>
        <location filename="../../desktops.cpp" line="99"/>
        <source>(Unnamed desktop)</source>
        <translation>(Naamloos werkblad)</translation>
    </message>
    <message>
        <location filename="../../mouse.cpp" line="57"/>
        <source>Custom actions</source>
        <translation>Aangepaste acties</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="76"/>
        <source>About ObConf-Qt</source>
        <translation>Over ObConf-Qt</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="77"/>
        <source>A preferences manager for Openbox

Copyright (c) 2014-2015

Authors:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

The program is based on ObConf developed by the following developers.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
        <translation>Een instellingenbeheerder voor Openbox

Auteursrecht (c) 2014-2015

Auteur:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

Het programma is gebaseerd op ObConf, ontwikkeld door:
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
    </message>
    <message>
        <source>A preferences manager for Openbox

Copyright (c) 2003-2013

Authors:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
        <translation type="vanished">graphische Benutzeroberfläche zur Konfiguration des Fenstermanagers Openbox

Copyright (c) 2003-2013

Autoren:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../archive.cpp" line="26"/>
        <source>&quot;%1&quot; was installed to %1</source>
        <translation>&quot;%1&quot; werd geïnstalleerd op %1</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="53"/>
        <source>&quot;%1&quot; was successfully created</source>
        <translation>&quot;%1&quot; werd met succes gemaakt</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="89"/>
        <source>Unable to create the theme archive &quot;%1&quot;.
The following errors were reported:
%2</source>
        <translation>Kon thema-archief &quot;%1&quot; niet maken.
        De volgende fouten werden gemeld:
        %2</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="95"/>
        <location filename="../../archive.cpp" line="178"/>
        <source>Unable to run the &quot;tar&quot; command: %1</source>
        <translation>Kon &quot;tar&quot; opdracht %1 niet uitvoeren</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="115"/>
        <source>Unable to create directory &quot;%1&quot;: %2</source>
        <translation>Kon map &quot;%1&quot; niet maken: %2</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="138"/>
        <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
        <translation>&quot;%1&quot; lijkt geen geldige map te zijn voor Openbox-thema&apos;s</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="148"/>
        <source>Unable to move to directory &quot;%1&quot;: %2</source>
        <translation>Kon niet verplaatsen naar map &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="185"/>
        <source>Unable to extract the file &quot;%1&quot;.
Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
The following errors were reported:
%3</source>
        <translation>Kon bestand &quot;%1&quot; niet uitpakken.
Zorg er a.u.b. voor, dat &quot;%2&quot; beschrijfbaar is en dat het bestand een geldig thema-archief is voor Openbox. De volgende fouten werden gemeld:
%3</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="53"/>
        <source>ObConf Error</source>
        <translation>Fout van ObConf-Qt</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="58"/>
        <source>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions. See the file COPYING for details.

</source>
        <translation>Auteursrecht (c) 2003-2008   Dana Jansens
Auteursrecht (c) 2003        Tim Riley
Auteursrecht (c) 2007        Javeed Shaikh
Auteursrecht (c) 2013        Hong Jen Yee (PCMan)

Op dit programma zit geen enkele garantie.
Dit is vrije programmatuur; u mag hem onder bepaalde voorwaarden
herverdelen. Zie het bestand COPYING voor bijzonderheden.

</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="73"/>
        <source>Syntax: obconf [options] [ARCHIVE.obt]

Options:
  --help                Display this help and exit
  --version             Display the version and exit
  --install ARCHIVE.obt Install the given theme archive and select it
  --archive THEME       Create a theme archive from the given theme directory
  --config-file FILE    Specify the path to the config file to use
</source>
        <translation>Zinsbouw: obconf [opties] [ARCHIVE.obt]

Opties:
  --help                Toon deze hulptekst en sluit het programma af
  --version             Toon de programmaversie en sluit het programma af
  --install ARCHIVE.obt Installeer en gebruik het opgegeven thema-archief
  --archive THEMA       Maak een thema-archief van de opgegeven themamap
  --config-file DATEI   Geef het pad op naar het te gebruiken instellingenbestand
  </translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="97"/>
        <source>--install requires an argument
</source>
        <translation>--install heeft een argument nodig</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="103"/>
        <source>--archive requires an argument
</source>
        <translation>--archive benötigt ein Argument</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="109"/>
        <source>--config-file requires an argument
</source>
        <translation>--config-file heeft een argument nodig</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="239"/>
        <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.

Message: %1</source>
        <translation>Fout bij het lezen van het instellingenbestand voor Openbox. Uw instellingenbestand is geen geldige XML.

Boodschap: %1</translation>
    </message>
    <message>
        <source>--archive requires an argument</source>
        <translation type="vanished">--archive heeft een argument nodig</translation>
    </message>
    <message>
        <source>--config-file requires an argument</source>
        <translation type="vanished">--config-file heeft een argument nodig</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="225"/>
        <location filename="../../obconf-qt.cpp" line="241"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="226"/>
        <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
        <translation>Kon bestand rc.xml niet laden. U hebt Openbox waarschijnlijk niet juist geïnstalleerd.</translation>
    </message>
    <message>
        <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.

        Message: %1</source>
        <translation type="vanished">Fout bij het lezen van het instellingenbestand voor Openbox. Uw instellingenbestand is geen geldige XML.
        
        Boodschap: %1</translation>
    </message>
</context>
</TS>
